pub struct CachedFfiTransaction { /* private fields */ }Expand description
A preprocessed Transaction which can be used to verify scripts within said Transaction.
Implementations
Sourceimpl CachedFfiTransaction
impl CachedFfiTransaction
Sourcepub fn new(
transaction: Arc<Transaction>,
all_previous_outputs: Arc<Vec<Output>>,
nu: NetworkUpgrade,
) -> Result<Self, Error>
pub fn new( transaction: Arc<Transaction>, all_previous_outputs: Arc<Vec<Output>>, nu: NetworkUpgrade, ) -> Result<Self, Error>
Construct a CachedFfiTransaction from a Transaction and the outputs
from previous transactions that match each input in the transaction
being verified.
Sourcepub fn all_previous_outputs(&self) -> &Vec<Output>
pub fn all_previous_outputs(&self) -> &Vec<Output>
Returns the outputs from previous transactions that match each input in the transaction being verified.
Sourcepub fn p2sh_sigops(&self) -> u32
pub fn p2sh_sigops(&self) -> u32
Returns the total number of P2SH sigops across all inputs of this transaction.
Mirrors zcashd’s GetP2SHSigOpCount().
For each P2SH input (where the spent scriptPubKey is P2SH), the redeem script (the last
data push in the scriptSig) is parsed in “accurate” mode and its sigops are counted.
Coinbase inputs contribute zero.
This must be included in the block-wide MAX_BLOCK_SIGOPS total to match zcashd’s consensus
behavior.