CachedFfiTransaction

Struct CachedFfiTransaction 

pub struct CachedFfiTransaction { /* private fields */ }
A preprocessed Transaction which can be used to verify scripts within said Transaction.

Implementations

Source

impl CachedFfiTransaction

pub fn new( transaction: Arc<Transaction>, all_previous_outputs: Arc<Vec<Output>>, nu: NetworkUpgrade, ) -> Result<Self, Error>

Construct a CachedFfiTransaction from a Transaction and the outputs from previous transactions that match each input in the transaction being verified.

pub fn inputs(&self) -> &[Input]

Returns the transparent inputs for this transaction.

pub fn all_previous_outputs(&self) -> &Vec<Output>

Returns the outputs from previous transactions that match each input in the transaction being verified.

pub fn sighasher(&self) -> &SigHasher

Return the sighasher being used for this transaction.

pub fn p2sh_sigops(&self) -> u32

Returns the total number of P2SH sigops across all inputs of this transaction.

Mirrors zcashd’s GetP2SHSigOpCount().

For each P2SH input (where the spent scriptPubKey is P2SH), the redeem script (the last data push in the scriptSig) is parsed in “accurate” mode and its sigops are counted. Coinbase inputs contribute zero.

This must be included in the block-wide MAX_BLOCK_SIGOPS total to match zcashd’s consensus behavior.

pub fn is_valid(&self, input_index: usize) -> Result<(), Error>

Verify if the script in the input at input_index of a transaction correctly spends the matching transparent::Output it refers to.