pub trait Sigops {
// Required method
fn scripts(&self) -> impl Iterator<Item = Vec<u8>>;
// Provided method
fn sigops(&self) -> Result<u32, Error> { ... }
}Expand description
Trait for counting the number of transparent signature operations in the transparent inputs and outputs of a transaction.
Mirrors zcashd’s GetLegacySigOpCount().
All transparent inputs are included, including the coinbase input script. zcashd charges
coinbase scriptSig sigops against the block MAX_BLOCK_SIGOPS limit, so Zebra must do the
same to avoid a consensus split.
Required Methods
Provided Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.